#[non_exhaustive]pub enum EventType {
TrackStartEvent,
TrackEndEvent,
TrackExceptionEvent,
TrackStuckEvent,
WebSocketClosedEvent,
}Expand description
The type of event being dispatched as a message from the server as the event triggers.
Variants (Non-exhaustive)
This enum is marked as non-exhaustive
Non-exhaustive enums could have additional variants added in future. Therefore, when matching against variants of non-exhaustive enums, an extra wildcard arm must be added to account for any future variants.
TrackStartEvent
Dispatched when a track starts playing.
TrackEndEvent
Dispatched when a track ends.
TrackExceptionEvent
Dispatched when a track throws an exception.
TrackStuckEvent
Dispatched when a track gets stuck while playing.
WebSocketClosedEvent
Dispatched when the websocket connection to Discord voice servers is closed.