#[non_exhaustive]pub struct VoiceState {
pub endpoint: String,
pub session_id: String,
pub token: String,
}Expand description
The Discord voice information that Lavalink uses for connection and sending information.
Fields (Non-exhaustive)
This struct is marked as non-exhaustive
Non-exhaustive structs could have additional fields added in future. Therefore, non-exhaustive structs cannot be constructed in external crates using the traditional
Struct { .. } syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.endpoint: StringThe Discord voice endpoint to connect to.
session_id: StringThe Discord voice session id to authenticate with. Note this is separate from the lavalink session id.
token: StringThe Discord voice token to authenticate with.